@@ -110,7 +110,7 @@ def check_produces_a_faulty_executable (bug, make, sources, regex, trigger):
 check_reports_an_error_but_should_not (
     bug = 244936,
     make = ("gnatmake", "p"),
-    regex = 'p\.ads:3:25: "foo" is hidden within declaration of instance',
+    regex = 'p\.ads:3:25: error: "foo" is hidden within declaration of instance',
     sources = (
         ("foo.ads", """generic
 procedure foo;
@@ -413,26 +413,6 @@ check_compiles_but_should_not (
 end Test_80;
 """),))
 
-check_compiles_but_should_not (
-    bug = 248680,
-    make = ("gnatmake", "test_90"),
-    sources = (
-        ("test_90.adb", """procedure Test_90 is
-   type T1 is tagged null record;
-
-   procedure p1 (x : access T1) is
-      b: boolean;
-      y: aliased T1;
-   begin
-      B := Y'Access = X;     -- ERROR: no matching "="
---    B := X = Y'Access;     -- line 11: error detected
-   end p1;
-
-begin
-   null;
-end Test_90;
-"""),))
-
 check_compiles_but_should_not (
     bug = 248681,
     make = ("gnatmake", "test_91"),
@@ -487,7 +467,7 @@ end;
 check_reports_an_error_but_should_not (
     bug = 253737,
     make = ("gnatmake", "test_4"),
-    regex = 'test_4.ads:.:01: "pak2" not declared in "pak1"',
+    regex = 'test_4\.ads:3:01: error: "pak2" not declared in "pak1"',
     sources = (
         ("parent.ads", """generic
 package parent is
@@ -606,7 +586,7 @@ end Test_121;
 check_reports_an_error_but_should_not (
     bug = 276227,
     make = ("gnatmake", "test_124"),
-    regex = 'test_124\.ads:6:35: size for "T_arr_constrained" too small, minimum allowed is 256',
+    regex = 'test_124\.ads:6:35: error: size for "T_arr_constrained" too small, minimum allowed is 256',
     sources = (
         ("test_124.ads", """package Test_124 is
    type T is range 1 .. 32;
@@ -620,7 +600,7 @@ end Test_124;
 check_reports_an_error_but_should_not (
     bug = 278687,
     make = ("gnatmake", "test_127"),
-    regex = 'test_127\.adb:1.:21: expected type "T2" defined at line .',
+    regex = 'test_127\.adb:10:21: error: expected type "T2" defined at line 4',
     sources = (
         ("test_127.ads", """-- The second parameter of T2'Class'Read is of type T2'Class,
 -- which should match an object of type T3, which is derived
@@ -665,10 +645,7 @@ end Test_128;
 check_reports_an_error_but_should_not (
     bug = 279893,
     make = ("gnatmake", "test_129"),
-    regex = """gcc-[0-9.]+ -c test_129\.ads
-test_129\.ads:1.:49: designated type of actual does not match that of formal "T2"
-test_129\.ads:1.:49: instantiation abandoned
-gnatmake: "test_129\.ads" compilation error$""",
+    regex = 'test_129\.ads:13:49: error: designated type of actual does not match that of formal "T2"',
     sources = (
         ("pak1.ads", """-- legal instantiation rejected; illegal instantiation accepted
 -- adapted from John Woodruff c.l.a. post
@@ -712,7 +689,7 @@ print ("# Please ignore the gnatlink message.")
 check_reports_an_error_but_should_not (
     bug = 280939,
     make = ("gnatmake", "test_130"),
-    regex = "test_130\.adb:\(\.text\+0x5\): undefined reference to \`p2\'",
+    regex = "test_130\.adb:.*: undefined reference to \`p2\'",
     sources = (
         ("pak1.ads", """--  RM 10.1.5(4) "the pragma shall have an argument that is a name
 --  denoting that declaration."
@@ -822,7 +799,7 @@ end pak1;
 check_reports_an_error_but_should_not (
     bug = 660698,
     make = ("gnatmake", "proc.adb"),
-    regex = 'proc\.adb:17:28: there is no applicable operator "And" for type "Standard\.Integer"',
+    regex = 'proc\.adb:17:28: error: there is no applicable operator "And" for type "Standard\.Integer"',
     sources = (
         ("proc.adb", """procedure Proc is
    package P1 is
@@ -846,56 +823,12 @@ begin
 end Proc;
 """), ))
 
-check_produces_a_faulty_executable (
-    bug = 737225,
-    make = ("gnatmake", "round_decimal"),
-    trigger = "round_decimal",
-    regex = "Bug reproduced.",
-    sources = (
-        ("round_decimal.adb", """with Ada.Text_IO;
-
-procedure Round_Decimal is
-
-   --  OJBECTIVE:
-   --    Check that 'Round of a decimal fixed point type does round
-   --    away from zero if the operand is of a decimal fixed point
-   --    type with a smaller delta.
-
-   Unexpected_Compiler_Bug : exception;
-
-   type Milli is delta 0.001 digits 9;
-   type Centi is delta 0.01 digits 9;
-
-   function Rounded (Value : Milli) return Centi;
-   --  Value, rounded using Centi'Round
-
-   function Rounded (Value : Milli) return Centi is
-   begin
-      return Centi'Round (Value);
-   end Rounded;
-
-begin
-   --  Operands used directly:
-   if not (Milli'Round (0.999) = Milli'(0.999)
-             and
-           Centi'Round (0.999) = Centi'(1.0)
-             and
-           Centi'Round (Milli'(0.999)) = Centi'(1.0))
-   then
-      raise Unexpected_Compiler_Bug;
-   end if;
-   if Rounded (Milli'(0.999)) /= Centi'(1.0) then
-      Ada.Text_IO.Put_Line ("Bug reproduced.");
-   end if;
-end Round_Decimal;
-"""),))
-
 # Even if an error is reported, the problem with the atomic variable
 # should be checked.
 check_reports_an_error_but_should_not (
     bug = 643663,
     make = ("gnatmake", "test"),
-    regex = 'test\.adb:4:25: no value supplied for component "Reserved"',
+    regex = 'test\.adb:4:25: error: no value supplied for component "Reserved"',
     sources = (
         ("pkg.ads", """package Pkg is
    type Byte is mod 2**8;
